pub struct ServiceUploadDocument {
    pub content_type: ContentType,
    pub content_length: f32,
    pub content_md5: Option<String>,
}
ServiceUploadDocument : Input for to be uploaded document.

Fields

content_type: ContentType

The content type of the to-be-uploaded file

content_length: f32

The content length of the to-be-uploaded file

content_md5: Option<String>

An MD5 hash of the content to be submitted to the upload destination. This value is used to determine if the data has been corrupted or tampered with during transit.

Implementations

Input for to be uploaded document.